import 'dart:collection';
import 'dart:convert';
import 'dart:developer';

import 'package:basic_utils/basic_utils.dart';
import 'package:easynetflutter/easynet/exception/EasyException.dart';
import 'package:easynetflutter/easynet/log/Logger.dart';
import 'package:http/http.dart';

class WSUtil {

  static Logger logger = Logger(className: "WSUtil");

  static Future<Map<String, dynamic>> getRequest(
      {String url, Map<String, dynamic> param, Map<String,
          String> header}) async {
    logger.w("URL: $url, Params: ${param.toString()}, Header: ${header.toString()}");
    String contentStr = await getRequestString(
        url: url, param: param, header: header);
    Map<String, dynamic> data = json.decode(contentStr);
    return data;
  }

  static Future<Map<String, dynamic>> postRequest(
      {String url, Map<String, dynamic> param, Map<String,
          String> header}) async {
    logger.w("URL: $url, Params: ${param.toString()}, Header: ${header.toString()}");
    Response response = await HttpUtils.postForFullResponse(
        url, queryParameters: param, headers: header);
    if (response.statusCode >= 400) {
      throw EasyException("Erro ao acessar o endereço ${url}");
    } else {
      String contentStr = response.body;
      logger.w(contentStr);
      Map<String, dynamic> data = json.decode(contentStr);
      return data;
    }
  }

  static Future<String> getRequestString(
      {String url, Map<String, dynamic> param, Map<String,
          String> header}) async {
    logger.w("URL: $url, Params: ${param.toString()}, Header: ${header.toString()}");
    Response response = await HttpUtils.getForFullResponse(
        url, queryParameters: param, headers: header);
    if (response.statusCode >= 400) {
      throw EasyException("Erro ao acessar o endereço: ${url}");
    } else {
      String contentStr = response.body;
      logger.w(contentStr);
      return contentStr;
    }
  }

  static Future<String> postRequestJson(
      {String url, String json, Map<String,
          dynamic> header}) async {
    if (header == null) {
      header = LinkedHashMap<String, String>();
    }
    MapEntry<String, String> entryContentType = MapEntry<String, String>("content-type", "application/json; charset=utf-8 ");
    List<MapEntry<String, String>> listEntrys = List();
    listEntrys.add(entryContentType);
    header.addEntries(listEntrys);
    logger.w("URL: $url, Json: ${json}, Header: ${header.toString()}");
    Response response = await HttpUtils.postForFullResponse(url, body: json, headers: header );
    if (response.statusCode >= 400) {
      throw EasyException("Erro ao acessar o endereço: ${url}");
    } else {
      String contentStr = response.body;
      logger.w(contentStr);
      return contentStr;
    }
  }
}
