import 'dart:developer';

import 'package:easynetflutter/easynet/log/Logger.dart';
import 'package:easynetflutter/easynet/model/NotificationPush.dart';
import 'package:flutter/material.dart';

abstract class LifecycleWatcherState<T extends StatefulWidget> extends State<T>
    with WidgetsBindingObserver {
  static Map<String, Logger> mapLogger = Map();
  @protected
  GlobalKey<ScaffoldState> scaffoldKey = GlobalKey<ScaffoldState>();

  @protected
  Logger getLogger() {
    String className = this.toString();
    if (mapLogger.containsKey(className)) {
      return mapLogger[className];
    }
    Logger logger = Logger(className: this.toString());
    mapLogger[className] = logger;
    return logger;
  }

  @protected
  AppLifecycleState state;

  @override
  Widget build(BuildContext context) {
    return null;
  }

  @override
  void initState() {
    super.initState();
    getLogger().w("initState Generico");
    WidgetsBinding.instance.addObserver(this);
    WidgetsBinding.instance
        .addPostFrameCallback((_) => onStart());
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    onDestroy();
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    getLogger().w("didChangeAppLifecycleState " + state.toString());
    this.state = state;
    switch (state) {
      case AppLifecycleState.resumed:
        onResumed();
        break;
      case AppLifecycleState.inactive:
        onPaused();
        break;
      case AppLifecycleState.paused:
        onInactive();
        break;
      case AppLifecycleState.detached:
        onDetached();
        break;
    }
  }

  void onMessagePush(NotificationPush notificationPush) {
    getLogger().w("OnMessagePush " + notificationPush.messagePush.title);
    getLogger().w("OnMessagePush " + notificationPush.messagePush.body);
  }
  void onResumePush(NotificationPush notificationPush) {

  }
  void onLaunchPush(NotificationPush notificationPush) {

  }

  void onCreateToken(String token) {
    getLogger().w("onCreateToken ${this.toString()}");
  }
  void onStart() {
    getLogger().w("onStart ${this.toString()}");
  }

  void onResumed(){
    getLogger().w("onResumed ${this.toString()}");
  }

  void onPaused(){
    getLogger().w("onPaused ${this.toString()}");
  }

  void onInactive(){
    getLogger().w("onInactive ${this.toString()}");
  }

  void onDetached(){
    getLogger().w("onDetached ${this.toString()}");
  }

  void onDestroy(){
    getLogger().w("onDestroy ${this.toString()}");
  }

  void showSnackBar( {String message}) {
    getLogger().w("SnackBar $message");
    final snackBar = SnackBar(
      content: Text(message),
      action: SnackBarAction(
        label: 'Esconder',
        onPressed: () {
          // Código para desfazer a ação!
        },
      ),
    );
    scaffoldKey.currentState.showSnackBar(snackBar);
  }
}